from ....Methods.Import import ImportError


class MatFileError(ImportError):
    """Raised when the file_path is wrong or the variable is missing"""

    pass
